==> cxf-servlet-deployer-1.0.1-sources.jar: org/ow2/jonas/camel/cxf/servlet/OsgiCXFServletDeployer.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: OsgiCXFServletDeployer.java 17623 2009-06-12 12:31:50Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.camel.cxf.servlet;

import java.util.Dictionary;
import java.util.Hashtable;

import org.apache.cxf.Bus;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.http.HttpContext;
import org.osgi.service.http.HttpService;

/**
 * @author Guillaume Porcher
 */
public class OsgiCXFServletDeployer {

    private OsgiHttpServiceCXFServlet cxf;

    // Injected by iPOJO
    private HttpService m_httpService;

    private String m_servletPath;

    private String m_busName;

    private final BundleContext bundleContext;

    private ServiceRegistration serviceRegistration;

    public OsgiCXFServletDeployer(final BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    public void start() throws Throwable {
        try {
            // Create CXFServlet
            this.cxf = new OsgiHttpServiceCXFServlet(this.m_servletPath);

            // Register servlet
            final HttpContext context = this.m_httpService.createDefaultHttpContext();
            this.m_httpService.registerServlet(this.m_servletPath, this.cxf, null, context);

            // Update servlet bus
            final Bus bus = this.cxf.getBus();

            // add bus to OSGI context
            final Dictionary<String, String> properties = new Hashtable<String, String>();
            properties.put("name", this.m_busName);
            this.serviceRegistration = this.bundleContext.registerService(Bus.class.getName(), bus, properties);
        } catch (final Throwable t) {
            t.printStackTrace();
            throw t;
        }
    }

    public void stop() throws Throwable {
        try {
            if (this.m_httpService != null) {
                this.m_httpService.unregister(this.m_servletPath);
            }
            if (this.serviceRegistration != null) {
                this.serviceRegistration.unregister();
            }
        } catch (final Throwable t) {
            t.printStackTrace();
            throw t;
        }
    }
}

==> cxf-servlet-deployer-1.0.4-sources.jar: org/ow2/jonas/camel/cxf/servlet/OsgiCXFServletDeployer.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: OsgiCXFServletDeployer.java 17810 2009-06-25 15:15:21Z porcherg $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.camel.cxf.servlet;

import java.util.Dictionary;
import java.util.Hashtable;

import org.apache.cxf.Bus;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.http.HttpContext;
import org.osgi.service.http.HttpService;

/**
 * @author Guillaume Porcher
 */
public class OsgiCXFServletDeployer {

    private OsgiHttpServiceCXFServlet cxf;

    // Injected by iPOJO
    private HttpService m_httpService;

    private String m_servletPath;

    private String m_busName;

    private String m_busConfig = null;

    private final BundleContext bundleContext;

    private ServiceRegistration serviceRegistration;

    public OsgiCXFServletDeployer(final BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }

    public void start() throws Throwable {
        try {
            // Create CXFServlet
            this.cxf = new OsgiHttpServiceCXFServlet(this.m_servletPath, this.m_busConfig);

            // Register servlet
            final HttpContext context = this.m_httpService.createDefaultHttpContext();
            this.m_httpService.registerServlet(this.m_servletPath, this.cxf, null, context);

            // Update servlet bus
            final Bus bus = this.cxf.getBus();

            // add bus to OSGI context
            final Dictionary<String, String> properties = new Hashtable<String, String>();
            properties.put("name", this.m_busName);
            this.serviceRegistration = this.bundleContext.registerService(Bus.class.getName(), bus, properties);
        } catch (final Throwable t) {
            t.printStackTrace();
            throw t;
        }
    }

    public void stop() throws Throwable {
        try {
            if (this.m_httpService != null) {
                this.m_httpService.unregister(this.m_servletPath);
            }
            if (this.serviceRegistration != null) {
                this.serviceRegistration.unregister();
            }
        } catch (final Throwable t) {
            t.printStackTrace();
            throw t;
        }
    }
}
